summaryrefslogtreecommitdiff
path: root/lang/python/python3-sqlparse/Makefile
diff options
context:
space:
mode:
authorRosen Penev <rosenp@gmail.com>2020-07-18 15:43:19 -0700
committerRosen Penev <rosenp@gmail.com>2020-10-10 00:00:05 -0700
commitdcc79a8d2fce332c4b0d2cf383c88106d0f7ca4c (patch)
tree8932054ec5d6e227e00435e6e476cfd312c80066 /lang/python/python3-sqlparse/Makefile
parentba147d0d407dafe4e7ae82129d0b06056ce7fdba (diff)
spice: convert to meson
Faster compilation. Removed autotools patches. Backported meson patch to fix compilation and pkgconfig file. Before: time make package/spice/compile -j 12 Executed in 62.85 secs fish external usr time 56.45 secs 276.00 micros 56.45 secs sys time 8.06 secs 46.00 micros 8.06 secs Before + PKG_BUILD_PARALLEL: Executed in 45.40 secs fish external usr time 63.08 secs 253.00 micros 63.08 secs sys time 8.57 secs 44.00 micros 8.57 secs After: time make package/spice/compile -j 12 Executed in 16.54 secs fish external usr time 41.29 secs 266.00 micros 41.29 secs sys time 4.76 secs 45.00 micros 4.76 secs Signed-off-by: Rosen Penev <rosenp@gmail.com>
Diffstat (limited to 'lang/python/python3-sqlparse/Makefile')
0 files changed, 0 insertions, 0 deletions